﻿using DevExpress.DataAccess.Excel;
using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraPivotGrid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.pivotGridControl.OptionsView.GroupFieldsInCustomizationWindow = true;

            PivotGridField categoryNameField = new PivotGridField()
            {
                FieldName = "CategoryName",
                Caption   = "Category Name",
                Area      = PivotArea.RowArea,
                AreaIndex = 0
            };

            PivotGridField productNameField = new PivotGridField()
            {
                FieldName = "ProductName",
                Caption   = "Product Name",
                Area      = PivotArea.RowArea,
                AreaIndex = 1
            };

            PivotGridField extendedPriceField = new PivotGridField()
            {
                FieldName = "Extended Price",
                Caption   = "Extended Price",
                Area      = PivotArea.DataArea,
                AreaIndex = 0
            };

            extendedPriceField.CellFormat.FormatType   = FormatType.Numeric;
            extendedPriceField.CellFormat.FormatString = "c2";

            PivotGridField orderDateField1 = new PivotGridField()
            {
                FieldName     = "OrderDate",
                Caption       = "Year",
                Area          = PivotArea.ColumnArea,
                AreaIndex     = 0,
                GroupInterval = PivotGroupInterval.DateYear,
            };

            PivotGridField orderDateField2 = new PivotGridField()
            {
                FieldName     = "OrderDate",
                Caption       = "Quarter",
                Area          = PivotArea.ColumnArea,
                AreaIndex     = 1,
                GroupInterval = PivotGroupInterval.DateQuarter
            };

            PivotGridField countryField = new PivotGridField()
            {
                FieldName = "Country",
                Caption   = "Country",
                AreaIndex = 0
            };

            countryField.FilterValues.Clear();

            countryField.FilterValues.FilterType = PivotFilterType.Included;

            countryField.FilterValues.Add("USA");

            this.pivotGridControl.Fields.AddRange
            (
                new PivotGridField[]
                {
                    categoryNameField,
                    productNameField,
                    orderDateField1,
                    orderDateField2,
                    extendedPriceField,
                    countryField
                }
            );

            ExcelDataSource dataSource = new ExcelDataSource();

            dataSource.FileName = "SalesPerson.xlsx";

            ExcelWorksheetSettings settings = new ExcelWorksheetSettings("Data");

            dataSource.SourceOptions = new ExcelSourceOptions(settings);

            dataSource.Fill();

            this.pivotGridControl.DataSource = dataSource;

            this.pivotGridControl.BestFit();
        }

        #endregion
    }
}